==> rapid_widgets_library-0.2.42.tar.gz: lib/custom-drawer.dart <==
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:flutter/material.dart';

class NavigationDrawer extends StatefulWidget {
  final DrawerParameters drawerParameters;
  NavigationDrawer({this.drawerParameters});

  @override
  _NavigationDrawerState createState() => _NavigationDrawerState();
}

class _NavigationDrawerState extends State<NavigationDrawer> {

  Widget buildHeader(){
    return (widget.drawerParameters.phone!='null'||widget.drawerParameters.email!='null'||widget.drawerParameters.name!='null'||widget.drawerParameters.urlImage!='null')?
    Container(
      padding: EdgeInsets.symmetric(vertical: 10),
      child: Column(

        children: [
          Padding(
            padding: const EdgeInsets.only(left: 200, bottom: 10),
            child: GestureDetector(
                onTap: (){
                  Navigator.pop(context);
                },
                child: Icon(Icons.clear,color: Colors.black,)),
          ),

          Wrap(
            children: [
              (widget.drawerParameters.urlImage!='null')?Padding(
                padding: const EdgeInsets.only(bottom: 25),
                child: CircleAvatar(radius: 30, backgroundImage: NetworkImage(widget.drawerParameters.urlImage)),
              ):CircleAvatar(radius: 30, backgroundColor: Colors.transparent,),
              SizedBox(width: 150),
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  (widget.drawerParameters.name!='null')? Text(widget.drawerParameters.name, style: TextStyle(fontSize: 14, color: Colors.black, fontWeight: FontWeight.bold)) :SizedBox.shrink(),
                  (widget.drawerParameters.name!='null')?const SizedBox(height: 4):SizedBox.shrink(),
                  (widget.drawerParameters.email!='null')?Text(widget.drawerParameters.email, style: TextStyle(fontSize: 12, color: Colors.black), overflow: TextOverflow.clip,):SizedBox.shrink(),
                  (widget.drawerParameters.email!='null')?const SizedBox(height: 2):SizedBox.shrink(),
                  (widget.drawerParameters.phone!='null')?Text(widget.drawerParameters.phone, style: TextStyle(fontSize: 12, color: Colors.black),):SizedBox.shrink(),
                ],
              ),
            ],
          ),
          const SizedBox(height: 10),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 10),
            child: Divider(color: Colors.grey, thickness: 0.5),
          ),
        ],
      ),
    ):
    SizedBox(
      height: 20,
      child: Padding(
        padding: const EdgeInsets.only(left: 210,top: 5),
        child: GestureDetector(
            onTap: (){
              Navigator.pop(context);
            },
            child: Icon(Icons.clear,color: Colors.black,)),
      ) ,
    );
  }

  Widget buildMenuItem({
    String text,
    IconData icon,
    Color  iconTextColor
  }) {
    final hoverColor = widget.drawerParameters.hoverColor;
    return (text!='null' || icon!=null)?Padding(
      padding: const EdgeInsets.symmetric(horizontal: 2),
      child: (icon!=null)?ListTile(
        leading: Icon(icon, color: iconTextColor??Colors.black),
        title: (text!='null')?Text(text, style: TextStyle(color: iconTextColor??Colors.black)):SizedBox.shrink(),
        hoverColor: hoverColor,
        onTap: (){
          return (widget.drawerParameters.ontap!=null)?widget.drawerParameters.ontap:null;
        },
      ):ListTile(
        title: (text!='null')?Text(text, style: TextStyle(color: iconTextColor??Colors.black)):SizedBox.shrink(),
        hoverColor: hoverColor,
        onTap: (){
          return (widget.drawerParameters.ontap!=null)?widget.drawerParameters.ontap:null;
        },
      ),
    ):SizedBox.shrink();
  }

  @override
  Widget build(BuildContext context) {

    return Container(
      width: 250,
      child: Drawer(
        child: Material(
          color: widget.drawerParameters.drawerColor,
          child: ListView(
            children: [
              buildHeader(),
              (widget.drawerParameters.items!=null)?Container(
                child: Column(
                  children: [
                    const SizedBox(height: 12),
                    for(int i =0; i<widget.drawerParameters.items.length;i++)
                      for(var key in widget.drawerParameters.items[i].keys)
                      /*if(widget.drawerParameters.items[i].keys!='null' || widget.drawerParameters.items[i][key]!=null )*/
                        buildMenuItem(
                            text: key,
                            icon: widget.drawerParameters.items[i][key],
                            iconTextColor: widget.drawerParameters.iconTextColor
                        ),
                    SizedBox(height: 12),
                  ],
                ),
              ):SizedBox.shrink(),
            ],
          ),
        ),
      ),
    );
  }
}

==> rapid_widgets_library-0.2.46.tar.gz: lib/custom-drawer.dart <==
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';

class NavigationDrawer extends StatefulWidget {
  final DrawerParameters drawerParameters;
  NavigationDrawer({this.drawerParameters});

  @override
  _NavigationDrawerState createState() => _NavigationDrawerState();
}

class _NavigationDrawerState extends State<NavigationDrawer> {

  Widget buildHeader(){
    return (widget.drawerParameters.phone!='null'||widget.drawerParameters.email!='null'||widget.drawerParameters.name!='null'||widget.drawerParameters.urlImage!='null')?
    Container(
      padding: EdgeInsets.symmetric(vertical: 10),
      child: Column(

        children: [
          Padding(
            padding: const EdgeInsets.only(left: 200, bottom: 10),
            child: GestureDetector(
                onTap: (){
                  Navigator.pop(context);
                },
                child: Icon(Icons.clear,color: Colors.black,)),
          ),

          Wrap(
            children: [
              (widget.drawerParameters.urlImage!='null')?Padding(
                padding: const EdgeInsets.only(bottom: 25),
                child: CircleAvatar(radius: 30, backgroundImage: NetworkImage(widget.drawerParameters.urlImage)),
              ):CircleAvatar(radius: 30, backgroundColor: Colors.transparent,),
              SizedBox(width: 150),
              Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  (widget.drawerParameters.name!='null')? Text(widget.drawerParameters.name, style: GoogleFonts.getFont('Roboto',fontSize: 14, color: Colors.black, fontWeight: FontWeight.bold)) :SizedBox.shrink(),
                  (widget.drawerParameters.name!='null')?const SizedBox(height: 4):SizedBox.shrink(),
                  (widget.drawerParameters.email!='null')?Text(widget.drawerParameters.email, style: GoogleFonts.getFont('Roboto',fontSize: 12, color: Colors.black), overflow: TextOverflow.clip,):SizedBox.shrink(),
                  (widget.drawerParameters.email!='null')?const SizedBox(height: 2):SizedBox.shrink(),
                  (widget.drawerParameters.phone!='null')?Text(widget.drawerParameters.phone, style: GoogleFonts.getFont('Roboto',fontSize: 12, color: Colors.black),):SizedBox.shrink(),
                ],
              ),
            ],
          ),
          const SizedBox(height: 10),
          Padding(
            padding: const EdgeInsets.symmetric(horizontal: 10),
            child: Divider(color: Colors.grey, thickness: 0.5),
          ),
        ],
      ),
    ):
    SizedBox(
      height: 20,
      child: Padding(
        padding: const EdgeInsets.only(left: 210,top: 5),
        child: GestureDetector(
            onTap: (){
              Navigator.pop(context);
            },
            child: Icon(Icons.clear,color: Colors.black,)),
      ) ,
    );
  }

  Widget buildMenuItem({
    String text,
    IconData icon,
    Color  iconTextColor
  }) {
    final hoverColor = widget.drawerParameters.hoverColor;
    return (text!='null' || icon!=null)?Padding(
      padding: const EdgeInsets.symmetric(horizontal: 2),
      child: (icon!=null)?ListTile(
        leading: Icon(icon, color: iconTextColor??Colors.black),
        title: (text!='null')?Text(text, style: GoogleFonts.getFont('Roboto',color: iconTextColor??Colors.black)):SizedBox.shrink(),
        hoverColor: hoverColor,
        onTap: (){
          return (widget.drawerParameters.ontap!=null)?widget.drawerParameters.ontap:null;
        },
      ):ListTile(
        title: (text!='null')?Text(text, style: GoogleFonts.getFont('Roboto',color: iconTextColor??Colors.black)):SizedBox.shrink(),
        hoverColor: hoverColor,
        onTap: (){
          return (widget.drawerParameters.ontap!=null)?widget.drawerParameters.ontap:null;
        },
      ),
    ):SizedBox.shrink();
  }

  @override
  Widget build(BuildContext context) {

    return Container(
      width: 250,
      child: Drawer(
        child: Material(
          color: widget.drawerParameters.drawerColor,
          child: ListView(
            children: [
              buildHeader(),
              (widget.drawerParameters.items!=null)?Container(
                child: Column(
                  children: [
                    const SizedBox(height: 12),
                    for(int i =0; i<widget.drawerParameters.items.length;i++)
                      for(var key in widget.drawerParameters.items[i].keys)
                      /*if(widget.drawerParameters.items[i].keys!='null' || widget.drawerParameters.items[i][key]!=null )*/
                        buildMenuItem(
                            text: key,
                            icon: widget.drawerParameters.items[i][key],
                            iconTextColor: widget.drawerParameters.iconTextColor
                        ),
                    SizedBox(height: 12),
                  ],
                ),
              ):SizedBox.shrink(),
            ],
          ),
        ),
      ),
    );
  }
}
